@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2020, kachelaqa <kachelaqa@gmail.com>
+# Copyright (C) 2010-2021, kachelaqa <kachelaqa@gmail.com>
 
 import sys, os, re, glob, copy, errno, socket, json
 import urllib.request, urllib.error, http.client
@@ -574,8 +574,7 @@ class Backend(object):
                 raise DatabaseError(dbpath, error)
             elif error:
                 raise DatabaseError(None, error)
-            arch = config.get('Architecture')
-            if arch:
+            for arch in config.get('Architecture', ()):
                 alpm.option_set_arch(arch)
             for name in config['Repositories']:
                 if alpm.register_syncdb(name) is None:
