@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2020, kachelaqa <kachelaqa@gmail.com>
+# Copyright (C) 2010-2021, kachelaqa <kachelaqa@gmail.com>
 
 import os, re, glob, time, signal
 import urllib.request
@@ -20,7 +20,7 @@ PM_CACHE_DIRS = ('/var/cache/pacman/pkg',)
 
 match_pkgfile = re.compile(r"""
     ^(.+)-([^-\s]+-[^-\s]+)-(i686|x86_64|any)
-    \.pkg\.tar(?:\.(?:gz|bz2|xz|Z))?$
+    \.pkg\.tar(?:\.\w+)?$
     """, re.X).match
 
 
@@ -32,9 +32,9 @@ def read_config(path=PM_CONF_FILE, section=None, config=None):
             'SigLevels': defaultdict(list),
             }
     repeating = set((
-        'CacheDir', 'CleanMethod', 'HoldPkg', 'IgnoreGroup',
-        'IgnorePkg', 'NoExtract', 'NoUpgrade', 'SigLevel',
-        'LocalFileSigLevel', 'RemoteFileSigLevel',
+        'Architecture', 'CacheDir', 'CleanMethod', 'HoldPkg',
+        'IgnoreGroup', 'IgnorePkg', 'NoExtract', 'NoUpgrade',
+        'SigLevel', 'LocalFileSigLevel', 'RemoteFileSigLevel',
         ))
     with open(path, 'r') as stream:
         for line in stream:
@@ -56,15 +56,13 @@ def read_config(path=PM_CONF_FILE, section=None, config=None):
                     read_config(path, section, config)
             elif section == 'options':
                 if value:
-                    if key == 'Architecture':
-                        if key in config:
-                            continue
-                        if value == 'auto':
-                            value = os.uname()[4]
-                    elif key in repeating:
+                    if key in repeating:
                         if key == 'CacheDir':
                             value = [value]
                         else:
+                            if key == 'Architecture':
+                                value = re.sub(
+                                    r'\bauto\b', value, os.uname()[4])
                             value = value.split()
                         if key in config:
                             config[key].extend(value)
@@ -74,9 +72,9 @@ def read_config(path=PM_CONF_FILE, section=None, config=None):
                 config[key] = value
             elif key == 'Server':
                 server = value.replace('$repo', section)
-                arch = config.get('Architecture')
-                if arch:
-                    server = server.replace('$arch', arch)
+                arches = config.get('Architecture')
+                if arches:
+                    server = server.replace('$arch', arches[0])
                 config['Servers'][section].append(server)
                 if section not in config['Repositories']:
                     config['Repositories'].append(section)
